pitchtools.NumberedPitchObject
==============================

.. inheritance-diagram:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject
   :private-bases:

.. autoclass:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Special Methods
---------------

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__abs__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__eq__

    Inherited from :py:class:`abctools.AttributeEqualityAbjadObject <abjad.tools.abctools.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject.AttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__float__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__ge__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__gt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__hash__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__int__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__le__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__lt__

    Inherited from :py:class:`abctools.SortableAttributeEqualityAbjadObject <abjad.tools.abctools.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject.SortableAttributeEqualityAbjadObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__ne__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`

.. automethod:: abjad.tools.pitchtools.NumberedPitchObject.NumberedPitchObject.NumberedPitchObject.__repr__

    Inherited from :py:class:`pitchtools.PitchObject <abjad.tools.pitchtools.PitchObject.PitchObject.PitchObject>`
